summaryrefslogtreecommitdiffstats
path: root/src/widgets/qtoolbutton.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/widgets/qtoolbutton.cpp')
-rw-r--r--src/widgets/qtoolbutton.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/widgets/qtoolbutton.cpp b/src/widgets/qtoolbutton.cpp
index f11b613..2f1b59b 100644
--- a/src/widgets/qtoolbutton.cpp
+++ b/src/widgets/qtoolbutton.cpp
@@ -716,10 +716,10 @@ void QToolButton::setOnIconSet( const QIconSet& set )
{
setIconSet( set );
/*
### Get rid of all qWarning in this file in 4.0.
Also consider inlining the obsolete functions then.
*/
- qWarning( "QToolButton::setOnIconSet(): This function is not supported"
+ tqWarning( "QToolButton::setOnIconSet(): This function is not supported"
" anymore" );
}
@@ -790,7 +790,7 @@ void QToolButton::setIconSet( const QIconSet & set )
void QToolButton::setIconSet( const QIconSet & set, bool /* on */ )
{
setIconSet( set );
- qWarning( "QToolButton::setIconSet(): 'on' parameter ignored" );
+ tqWarning( "QToolButton::setIconSet(): 'on' parameter ignored" );
}
#endif
@@ -716,10 +716,10 @@ void QToolButton::setOnIconSet( const QIconSet& set )
setIconSet( set );
/*
- ### Get rid of all qWarning in this file in 4.0.
+ ### Get rid of all tqWarning in this file in 4.0.
Also consider inlining the obsolete functions then.
*/